@@ -5,9 +5,8 @@ import inspect
 import os
 from os.path import isdir
 
-from plotly import utils, optional_imports
+from plotly import optional_imports
 from plotly.io import to_json, to_image, write_image, write_html
-from plotly.io._orca import ensure_server
 from plotly.io._utils import plotly_cdn_url
 from plotly.offline.offline import _get_jconfig, get_plotlyjs
 from plotly.tools import return_figure_from_figure_or_data
@@ -112,7 +111,6 @@ class ImageRenderer(MimetypeRenderer):
         scale=None,
         engine="auto",
     ):
-
         self.mime_type = mime_type
         self.b64_encode = b64_encode
         self.format = format
@@ -150,7 +148,7 @@ class PngRenderer(ImageRenderer):
     mime type: 'image/png'
     """
 
-    def __init__(self, width=None, height=None, scale=None, engine="auto"):
+    def __init__(self, width=None, height=None, scale=None, engine=None):
         super(PngRenderer, self).__init__(
             mime_type="image/png",
             b64_encode=True,
@@ -172,7 +170,7 @@ class SvgRenderer(ImageRenderer):
     mime type: 'image/svg+xml'
     """
 
-    def __init__(self, width=None, height=None, scale=None, engine="auto"):
+    def __init__(self, width=None, height=None, scale=None, engine=None):
         super(SvgRenderer, self).__init__(
             mime_type="image/svg+xml",
             b64_encode=False,
@@ -194,7 +192,7 @@ class JpegRenderer(ImageRenderer):
     mime type: 'image/jpeg'
     """
 
-    def __init__(self, width=None, height=None, scale=None, engine="auto"):
+    def __init__(self, width=None, height=None, scale=None, engine=None):
         super(JpegRenderer, self).__init__(
             mime_type="image/jpeg",
             b64_encode=True,
@@ -215,7 +213,7 @@ class PdfRenderer(ImageRenderer):
     mime type: 'application/pdf'
     """
 
-    def __init__(self, width=None, height=None, scale=None, engine="auto"):
+    def __init__(self, width=None, height=None, scale=None, engine=None):
         super(PdfRenderer, self).__init__(
             mime_type="application/pdf",
             b64_encode=True,
@@ -255,7 +253,6 @@ class HtmlRenderer(MimetypeRenderer):
         animation_opts=None,
         include_plotlyjs=True,
     ):
-
         self.config = dict(config) if config else {}
         self.auto_play = auto_play
         self.connected = connected
@@ -305,7 +302,6 @@ class HtmlRenderer(MimetypeRenderer):
             ipython_display.display_html(script, raw=True)
 
     def to_mimebundle(self, fig_dict):
-
         from plotly.io import to_html
 
         include_mathjax = "cdn"
@@ -410,7 +406,6 @@ class KaggleRenderer(HtmlRenderer):
     def __init__(
         self, config=None, auto_play=False, post_script=None, animation_opts=None
     ):
-
         super(KaggleRenderer, self).__init__(
             connected=True,
             full_html=False,
@@ -438,7 +433,6 @@ class AzureRenderer(HtmlRenderer):
     def __init__(
         self, config=None, auto_play=False, post_script=None, animation_opts=None
     ):
-
         super(AzureRenderer, self).__init__(
             connected=True,
             full_html=False,
@@ -463,7 +457,6 @@ class ColabRenderer(HtmlRenderer):
     def __init__(
         self, config=None, auto_play=False, post_script=None, animation_opts=None
     ):
-
         super(ColabRenderer, self).__init__(
             connected=True,
             full_html=True,
@@ -508,7 +501,6 @@ class IFrameRenderer(MimetypeRenderer):
         include_plotlyjs=True,
         html_directory="iframe_figures",
     ):
-
         self.config = config
         self.auto_play = auto_play
         self.post_script = post_script
@@ -540,7 +532,7 @@ class IFrameRenderer(MimetypeRenderer):
         # Make directory for
         try:
             os.makedirs(self.html_directory)
-        except OSError as error:
+        except OSError:
             if not isdir(self.html_directory):
                 raise
 
@@ -569,9 +561,7 @@ class IFrameRenderer(MimetypeRenderer):
     frameborder="0"
     allowfullscreen
 ></iframe>
-""".format(
-            width=iframe_width, height=iframe_height, src=self.build_url(filename)
-        )
+""".format(width=iframe_width, height=iframe_height, src=self.build_url(filename))
 
         return {"text/html": iframe_html}
 
@@ -590,7 +580,6 @@ class IFrameRenderer(MimetypeRenderer):
 
 
 class CoCalcRenderer(IFrameRenderer):
-
     _render_count = 0
 
     def build_filename(self):
@@ -701,7 +690,6 @@ class BrowserRenderer(ExternalRenderer):
         post_script=None,
         animation_opts=None,
     ):
-
         self.config = config
         self.auto_play = auto_play
         self.using = using
@@ -738,7 +726,6 @@ class DatabricksRenderer(ExternalRenderer):
         animation_opts=None,
         include_plotlyjs="cdn",
     ):
-
         self.config = config
         self.auto_play = auto_play
         self.post_script = post_script
@@ -809,7 +796,6 @@ class SphinxGalleryHtmlRenderer(HtmlRenderer):
         )
 
     def to_mimebundle(self, fig_dict):
-
         from plotly.io import to_html
 
         if self.connected:
@@ -841,7 +827,7 @@ class SphinxGalleryOrcaRenderer(ExternalRenderer):
         # Name of script from which plot function was called is retrieved
         try:
             filename = stack[3].filename  # let's hope this is robust...
-        except:  # python 2
+        except Exception:  # python 2
             filename = stack[3][1]
         filename_root, _ = os.path.splitext(filename)
         filename_html = filename_root + ".html"
